<?php
/**
 * Receives options from options page and saves the data. Also has function for testing the connection. 
 */


include_once( plugin_dir_path( __FILE__ ) . '../shared/payadvantage-auth.php' );
add_action( 'wp_ajax_save_pay_advantage_settings_action', 'save_pay_advantage_settings_handler' );

/**
 * Action that saves the data to the options table, called by the options page.
 */
function save_pay_advantage_settings_handler() {
    check_ajax_referer( 'pay_advantage_nonce', 'security' );
    
    if ( ! is_admin() ) {
        $return_message = json_encode (
            array(
            'success' => false,
            'Message' => 'Failed, user is not an admin.'
            )
        );
        echo $return_message;
        wp_die();
        return;
    }

    $env = sanitize_user( $_POST['payadvantageenv'] );
    $username = sanitize_user( $_POST['payadvantageusername'] );
    $password = wp_strip_all_tags( $_POST['payadvantagepassword'] );
    $require_mobile = filter_var( $_POST['payadvantagerequiremobile'], FILTER_VALIDATE_BOOLEAN ) ? 1 : 0;
    $require_address = filter_var( $_POST['payadvantagerequireaddress'], FILTER_VALIDATE_BOOLEAN ) ? 1 : 0;
    $show_credit_card = filter_var( $_POST['payadvantageshowbcreditcard'], FILTER_VALIDATE_BOOLEAN ) ? 1 : 0;
    $show_bpay = filter_var( $_POST['payadvantageshowbpay'], FILTER_VALIDATE_BOOLEAN ) ? 1 : 0;
    $description = sanitize_text_field( $_POST["payadvantagecarddescription"] );
    $anonymous_permission = filter_var( $_POST["payadvantageanonymouspermission"], FILTER_VALIDATE_BOOLEAN ) ? 1 : 0;

    $url = $env == "live" ? PAYADV_API_URL_LIVE : PAYADV_API_URL_SANDBOX;

    update_option( 'pay_advantage_url', $url );
    update_option( 'pay_advantage_env', $env );
    update_option( 'pay_advantage_user_name', $username );
    update_option( 'pay_advantage_password', $password );
    update_option( 'pay_advantage_credit_card_description', $description );
    update_option( 'pay_advantage_show_widget_to_users_not_logged_in', $anonymous_permission );
    update_option( 'pay_advantage_require_mobile', $require_mobile );
    update_option( 'pay_advantage_require_address', $require_address );
    update_option( 'pay_advantage_show_credit_card', $show_credit_card );
    update_option( 'pay_advantage_show_bpay', $show_bpay );

    $return_message = json_encode(
        array(
            'success' => true,
            'Message' => 'Success',
            'UserName' => $username,
            'RequireMobile' => $require_mobile
        )
    );

    echo $return_message;
    wp_die();
}

/**
 * this action is for testing credentials
 */
add_action('wp_ajax_pay_advantage_test_auth_action', 'pay_advantage_test_auth_handler');
function pay_advantage_test_auth_handler() {
    check_ajax_referer( 'pay_advantage_nonce', 'security' );

    if ( ! is_admin() ) {
        $return_message = json_encode(
            array(
                'success' => false,
                'Message' => 'Failed, user is not an admin.'
            )
        );
        echo $return_message;
        wp_die();
        return;
    }

    $auth = new Pay_Advantage_Auth();

    $env = sanitize_user($_POST['payadvantageenv']);
    $username = sanitize_user($_POST['payadvantageusername']);
    $password = wp_strip_all_tags( $_POST['payadvantagepassword'] );

    $auth_data = array(
        'username' => $username,
        'password' => $password
    );

    $url = $env == "live" ? PAYADV_API_URL_LIVE : PAYADV_API_URL_SANDBOX;
    $return_data = $auth->get_auth_token( $auth_data, $url );

    if (!isset($return_data['ErrorMessages'])) {
        $response =  array( 'Message' => 'Success', 'type' => 'AuthCheck' );
        $message = json_encode( $response );
        echo $message;
        wp_die();
    } else {
        $error_message = 'Failed: ' . $return_data['ErrorMessages'][0];
        $response =  array( 'Message' => $error_message, 'type' => 'AuthCheck' );
        $message = json_encode( $response );
        echo $message;
        wp_die();
    }
}

?>