<?php
/**
 * Contains setup for the options page. Sets up javascript and calls html for viewing the options page.
 */

include( plugin_dir_path( __FILE__ ) . '/html/options-html.php');

/**
 * Sets up menu items in settings tab of the admin screen.
 */
function pay_advantage_register_option_page() {
    add_options_page('Pay Advantage', 'Pay Advantage', 'manage_options', 'PayAdvantage', 'pay_advantage_options_page');
}

add_action('admin_menu', 'pay_advantage_register_option_page');
add_action( 'admin_enqueue_scripts', 'pay_advantage_options_page_load' );

/**
 * Sets up all the scripts for the page.
 */
function pay_advantage_options_page_load($handle) {

    if( 'settings_page_PayAdvantage' != $handle ) {
        return;
    }

    wp_register_script( 'pay_advantage_ajax_call', plugins_url( '../shared/js/ajax-call.js', __FILE__ ), array());
    wp_register_script( 'pay_advantage_options_page', plugins_url( '/js/options-page.js', __FILE__ ), array( 'pay_advantage_ajax_call' ));

    // in JavaScript, object properties are accessed as ajax_object.ajax_url, ajax_object.we_value
    wp_localize_script( 'pay_advantage_options_page', 'pay_advantage_ajax_object', array(
        'pay_advantage_ajax_url' => admin_url( 'admin-ajax.php' ),
        'pay_advantage_require_mobile' => get_option( 'pay_advantage_require_mobile' ),
        'pay_advantage_require_address' => get_option( 'pay_advantage_require_address' ),
        'pay_advantage_require_country' => get_option( 'pay_advantage_require_country' ),
        'pay_advantage_show_bpay' => get_option( 'pay_advantage_show_bpay' ),
        'pay_advantage_show_credit_card' => get_option( 'pay_advantage_show_credit_card' ),
        'pay_advantage_show_widget_to_users_not_logged_in' => get_option( 'pay_advantage_show_widget_to_users_not_logged_in' ),
        'pay_advantage_nonce'=> wp_create_nonce( 'pay_advantage_nonce' )
    ));

    //Activates the script
    wp_enqueue_script( 'pay_advantage_options_page' );
}

?>