<?php
/**
 * The plugin bootstrap file
 *
 * This file is read by WordPress to generate the plugin information in the plugin
 * admin area. This file also includes all of the dependencies used by the plugin,
 * registers the activation and deactivation functions, and defines a function
 * that starts the plugin.
 *
 * @link              https://www.payadvantage.com.au/
 * @since             1.0.0
 * @package           PayAdvantage
 *
 * @wordpress-plugin
 * Plugin Name:       Pay Advantage
 * Plugin URI:        https://www.payadvantage.com.au/
 * Description:       This plugin adds a payment gateway to Woo Commerce as well as a widget for credit card and BPay payments. 
 * Version:           2.1.0
 * Author:            Pay Advantage
 * Author URI:        ben.m@payadvantage.com
 * License:           GPL-2.0+
 * License URI:       http://www.gnu.org/licenses/gpl-2.0.txt
 * Text Domain:       PayAdvantage
 * Domain Path:       /languages
 */

/**
 * Current plugin version.
 */
define( 'PayAdvantage', '2.1.0' );

include( plugin_dir_path( __FILE__ ) . '/includes/payadvantage-files.php');

// Constants
define( 'PAYADV_APP_ID', 'wp-payadv' );
define( 'PAYADV_API_URL_SANDBOX', 'https://api.test.payadvantage.com.au/latest' );
define( 'PAYADV_API_URL_LIVE', 'https://api.payadvantage.com.au/latest' );
define( 'PAYADV_OPTIONS_REQUIRE_MOBILE', 1 );
define( 'PAYADV_OPTIONS_REQUIRE_ADDRESS', 0 );
define( 'PAYADV_OPTIONS_REQUIRE_COUNTRY', 0 );
define( 'PAYADV_OPTIONS_SHOW_BPAY', 1 );
define( 'PAYADV_OPTIONS_SHOW_CREDIT_CARD', 1 );
define( 'PAYADV_OPTIONS_CREDIT_CARD_DESCRIPTION', 'Pay Advantage' );
define( 'PAYADV_OPTIONS_SHOW_WIDGET_TO_USERS_NOT_LOGGED_IN', 0 );
define( 'PAYADV_MAX_LOG_SIZE_CHARS', 2000 );
define( 'PAYADV_DEFAULT_ERROR_LENGTH', 18 );

/**
 * The code that runs during plugin activation.
 * This action is documented in includes/class-padv-activator.php
 */
function activate_payadvantage() {
    require_once plugin_dir_path( __FILE__ ) . 'includes/class-payadvantage-activator.php';
    Pay_Advantage_Activator::activate();
}

/**
 * The code that runs during plugin deactivation.
 * This action is documented in includes/class-padv-deactivator.php
 */
function deactivate_payadvantage() {
    require_once plugin_dir_path( __FILE__ ) . 'includes/class-payadvantage-deactivator.php';
    Pay_Advantage_Deactivator::deactivate();
}

register_activation_hook( __FILE__, 'activate_payadvantage' );
register_deactivation_hook( __FILE__, 'deactivate_payadvantage' );

?>