/* eslint no-unused-vars: 0 */
/* eslint no-undef: 0 */

/**
 * Validates the amount as a null check.
 * @param {event from the input, needed to get values.} event
 * @param {the id for the field that shows the message.} messagId
 */
function validatePayAdvantageAmount (event, messagId) {
  if (validatePayAdvantageAgainstNulls(event, messagId, 'Amount is required.')) {
    return true
  };

  var amount = event.currentTarget.value
  var amountRegex = /^\d+(\.\d{1,2})?$/

  return payAdvantageSendResponse(messagId, amount, amountRegex, 'The Amount is invalid.')
}

/**
 * Validates email address as well as null check.
 * @param {event from the input, needed to get values.} event
 * @param {the id for the field that shows the message.} messagId
 */
function validatePayAdvantageEmailAddress (event, messagId) {
  if (validatePayAdvantageAgainstNulls(event, messagId, 'Email Address required.')) {
    return true
  }

  var email = event.currentTarget.value
  var emailRegex = /^(([^<>()[\]\\.,;:\s@"]+(\.[^<>()[\]\\.,;:\s@"]+)*)|(".+"))@((\[[0-9]{1,3}\.[0-9]{1,3}\.[0-9]{1,3}\.[0-9]{1,3}\])|(([a-zA-Z\-0-9]+\.)+[a-zA-Z]{2,}))$/

  return payAdvantageSendResponse(messagId, email, emailRegex, 'Email is Invalid.')
}

/**
 * Validates Mobile Numbers
 * @param {event from the input, needed to get values.} event
 * @param {the id for the field that shows the message.} messagId
 */
function validatePayAdvantageMobile (event, messagId) {
  if (validatePayAdvantageAgainstNulls(event, messagId, 'Mobile Phone Number is required.')) {
    return true
  };

  var phone = event.currentTarget.value
  var phoneRegex = /((?:\+|00)[17](?: |)?|(?:\+|00)[1-9]\d{0,2}(?: |)?|(?:\+|00)1\d{3}(?: |)?)?(0\d|\([0-9]{3}\)|[1-9]{0,3})(?:((?: |)[0-9]{2}) {4}|((?:[0-9]{2}) {4})|((?: |)[0-9]{3}(?: |)[0-9]{4})|([0-9]{7}))/g

  return payAdvantageSendResponse(messagId, phone, phoneRegex, 'Your Mobile Phone Number is Invalid.')
}

/**
 * Validates Card Holders Name
 * @param {event from the input, needed to get values.} event
 * @param {the id for the field that shows the message.} messagId
 */
function validatePayAdvantageCardHoldersName (event, messagId) {
  if (validatePayAdvantageAgainstNullsAndLettersOnly(event, messagId, 'Card Holders Name')) {
    return true
  };

  var cardHoldersName = event.currentTarget.value

  let nameArray = cardHoldersName.split(' ')

  if (nameArray.length !== 2) {
    jQuery(messagId).text('Card holder must have a first and last Name.')
    jQuery(messagId).show = true
    return true
  } else {
    jQuery(messagId).text('')
    jQuery(messagId).show = false

  }
}

/**
 * Validates Credit Card Number
 * @param {event from the input, needed to get values.} event
 * @param {the id for the field that shows the message.} messagId
 */
function validatePayAdvantageCreditCardNumber (event, messagId) {
  if (validatePayAdvantageAgainstNullsAndNumbersOnly(event, messagId, 'Credit Card number')) {
    return true
  };

  var creditCardNumber = event.currentTarget.value

  if (creditCardNumber.length !== 15 && creditCardNumber.length !== 16) {
    jQuery(messagId).text('Credit Card Number has an incorrect number of digits')
    jQuery(messagId).show = true
    return true
  }

  var visaMasterRegex = /^(?:4[0-9]{12}(?:[0-9]{3})?|5[1-5][0-9]{14})$/
  var amex = /^3[47][0-9]{13}$/

  if (visaMasterRegex.test(creditCardNumber) || amex.test(creditCardNumber)) {
    jQuery(messagId).text('')
    jQuery(messagId).show = false
    return false
  }

  jQuery(messagId).text('Credit Card Number is invalid.')
  jQuery(messagId).show = true
  return true
}

/**
 * Validates Credit Card Code
 * @param {event from the input, needed to get values.} event
 * @param {the id for the field that shows the message.} messagId
 */
function validatePayAdvantageCreditCardCode (event, messagId) {
  if (validatePayAdvantageAgainstNullsAndNumbersOnly(event, messagId, 'Credit Card Code')) {
    return true
  };

  var creditCardCode = event.currentTarget.value

  if (creditCardCode.length !== 3 && creditCardCode.length !== 4) {
    jQuery(messagId).text('Credit Card Code has an incorrect number of digits')
    jQuery(messagId).show = true
    return true
  }

  var codeRegex = /^[0-9]{3,4}$/
  return payAdvantageSendResponse(messagId, creditCardCode, codeRegex, 'Your Credit Card Code is Invalid.')
}

/**
 * A simple validator for null check.
 * @param {event from the input, needed to get values.} event
 * @param {the id for the field that shows the message.} messagId
 * @param {text to show the in the error message field.} messageText
 */
function validatePayAdvantageAgainstNulls (event, messagId, messageText) {
  if (event.currentTarget.value == null || event.currentTarget.value === '') {
    jQuery(messagId).text(messageText)
    jQuery(messagId).show = true
    return true
  }

  jQuery(messagId).text('')
  jQuery(messagId).show = true
  return false
}

function validatePayAdvantageAgainstNullsAndLettersOnly (event, messagId, fieldName) {
  if (validatePayAdvantageAgainstNulls(event, messagId, fieldName + ' is required')) {
    return true
  };

  var value = event.currentTarget.value

  var lettersOnly = /^[_A-z]*((-|\s)*[_A-z])*$/
  return payAdvantageSendResponse(messagId, value, lettersOnly, fieldName + ' should only contain letters')
}

function validatePayAdvantageAgainstNullsAndNumbersOnly (event, messagId, fieldName) {
  if (validatePayAdvantageAgainstNulls(event, messagId, fieldName + ' is required')) {
    return true
  };

  var value = event.currentTarget.value

  var numbersOnly = /^[0-9]*$/
  return payAdvantageSendResponse(messagId, value, numbersOnly, fieldName + ' should only contain numbers')
}

/**
 *
 * @param {the id for the html to send message to.} messagId
 * @param {the value comming through from the input.} testValue
 * @param {The regen to test against.} regex
 * @param {The message if the regex fails.} message
 */
function payAdvantageSendResponse (messagId, testValue, regex, message) {
  if (regex.test(testValue)) {
    jQuery(messagId).text('')
    jQuery(messagId).show = false
    return false
  }

  jQuery(messagId).text(message)
  jQuery(messagId).show = true
  return true
}
