<?php
/**
 * This method grabs objects and data from $_POST and turns it into json. 
 */


 class Pay_Advantage_Json_Converter{

    /**
     * Creates a json string to send to pay advantage.
     */    
    public function create_widget_customer_json_data() {
        $suburb = null;
        $state = null;
        $post_code = null;
        $street = null;

        if ( get_option( 'pay_advantage_require_address' ) == 1 ) {
            if ( $_POST['payadvantagesuburb'] != null ) {
                $suburb = sanitize_text_field( $_POST['payadvantagesuburb'] );
            }
            if ( $_POST['payadvantagestate'] != null ) {
                $state = sanitize_text_field( $_POST['payadvantagestate'] );
            } 
            if ( $_POST['payadvantagepostcode'] != null ) {
                $post_code = sanitize_text_field( $_POST['payadvantagepostcode'] );
            }
            if ( $_POST['payadvantagestreet'] != null ) {
                $street = sanitize_text_field( $_POST['payadvantagestreet'] );
            }
        }

        $data = array(
            'Name' => sanitize_text_field($_POST['payadvantagefirstname'] . ' ' . sanitize_text_field( $_POST['payadvantagelastname'] )),
            'Email' => sanitize_text_field($_POST['payadvantageemail']),
            'IsConsumer' => true,
            'FirstName' => sanitize_text_field($_POST['payadvantagefirstname']),
            'LastName' => sanitize_text_field($_POST['payadvantagelastname']),
            'Mobile' => $this->extract_phone_number( sanitize_text_field($_POST['payadvantagemobile']) ),
            'Street' => $street,
            'Suburb' => $suburb,
            'State' => $state,
            'Postcode' => $post_code,
            'BpayDetailsEmail' => 'force_send'
        );

        return json_encode( $data );
    }


    /**
     * creates the json customer data for sending with the api
     */
    public function create_customer_json( $data ) {
        $country_iso = null;

        if( !empty( $data['country'] ) ) {
            $country_iso = sanitize_text_field( $data['country'] );
        }

        $query = array(
            'Name' => sanitize_text_field( $data['first_name'] . ' ' . $data['last_name'] ),
            'Email' => sanitize_email( $data['email'] ),
            'IsConsumer' => true,
            'FirstName' => sanitize_text_field( $data['first_name'] ),
            'LastName' => sanitize_text_field( $data['last_name'] ),
            'CountryISO3316' => $country_iso
        );

        if( !empty( $data['address_1'] ) ) {
            $query['Street1'] = sanitize_text_field( $data['address_1'] );
        }

        if( !empty( $data['city'] ) ) {
            $query['Suburb'] = sanitize_text_field( $data['city'] );
        }

        if( !empty( $data['postcode'] ) ) {
            $query['Postcode'] = sanitize_text_field( $data['postcode'] );
        }

        if( !empty( $data['state'] ) ) {
            $query['State'] = sanitize_text_field( $data['state'] );
        }

        if ( !empty( $data['phone'] ) ) {
            $query['Phone'] = $this->extract_phone_number( sanitize_text_field( $data['phone'] ) );
            $query['PhoneCountryISO3316'] = $country_iso;
        }

        if ( !empty( $data['mobile'] ) ) {
            $query['Mobile'] = $this->extract_phone_number( sanitize_text_field( $data['mobile'] ) );
            $query['MobileCountryISO3316'] = $country_iso;
        }

        return json_encode( $query );
    }

    private function extract_phone_number ( $text_value ) {
        return preg_replace( '/[^0-9]/', '', $text_value );
    }

    /**
     * Creates the json for charging the credit card
     */
    public function create_payment_credit_card_charge_json( $amount, $description ) {
        $data = array(
            'cvn'=> sanitize_text_field( $_POST['payadvantagecreditcardcode'] ),
            'Amount'=> $amount,
            'OnchargeFees' => false,
            'Description' => $description,
            'ExternalID' => wp_generate_uuid4(),
            'ReceiptEmail' => 'force_send'
        );

        return json_encode($data);
    }

    /**
     * Creates the credit card token body
     */
    public function create_credit_card_token_json( $customer_code ){
        $data = array(
            'cvn'=> sanitize_text_field( $_POST['payadvantagecreditcardcode'] ),
            'cardholder'=> sanitize_text_field( $_POST['payadvantagecardholdersname'] ),
            'cardnumber'=> sanitize_text_field( $_POST['payadvantagecardnumber'] ),
            'expirymonth'=> sanitize_text_field( $_POST['payadvantageexpirymonth'] ),
            'expiryyear'=> sanitize_text_field( $_POST['payadvantageexpiryyear'] ),
            'customer'=> array(
                "code"=> $customer_code
            )
        );
        return json_encode( $data );
    }
}

?>