<?php
/**
 * Validates the ajax call information to make sure the data is valid.
 */

//Validation Tests
class Pay_Advantage_Validator {
    //Orchestrates BPay Reference Validation
    public function validate_bpay_register() {
        $validation_message = $this->customer_details_validation( '{"ErrorMessages":[' );
        
        if ( get_option( 'pay_advantage_require_mobile' ) == 1 ) {
            $validation_message = $this->validate_mobile( $validation_message );
        }

        if ( get_option( 'pay_advantage_require_address' ) == 1 ) {
            $validation_message = $this->pay_advantage_validate_address( $validation_message );
        }

        return $validation_message;
    }

    //Orchestrates Credit Card Payment Details
    public function validate_credit_card_payment() {
        $validation_message = $this->customer_details_validation( '{"ErrorMessages":[' );
        $validation_message = $this->validate_credit_card_details( $validation_message );

        return $validation_message;
    }

    // Validates the customers details. If its the first validator to run it should start with '{"ErrorMessages":['
    private function customer_details_validation( $validation_message ) {
        $validation_message = $this->check_if_start_of_validation( $validation_message );

        if ( ! $_POST['payadvantagefirstname'] ) {
            $validation_message = $validation_message . '"First name is required.",';
        }

        if ( ! $_POST['payadvantagelastname'] ) {
            $validation_message = $validation_message . '"Last name is required.",';
        }

        if ( ! $_POST['payadvantageemail'] ) {
            $validation_message = $validation_message . ' "Email is required.",';
        }   

        if ( $validation_message == '{"ErrorMessages":[' ) {
            return $validation_message;
        }

        return $this->check_if_end_of_validation( $validation_message );
    }


    //Validates the address. If its the first validator to run it should start with '{"ErrorMessages":['
    private function pay_advantage_validate_address( $validation_message ) {
        $validation_message = $this->check_if_start_of_validation( $validation_message );

        if ( ! $_POST['payadvantagestreet'] ) {
            $validation_message = $validation_message . '"Street is required.",';
        }
        if ( ! $_POST['payadvantagesuburb'] ) {
            $validation_message = $validation_message . '"Suburb is required.",';
        }
        if ( ! $_POST['payadvantagestate'] ) {
            $validation_message = $validation_message . '"State is required.",';
        }
        if ( ! $_POST['payadvantagepostcode'] ) {
            $validation_message = $validation_message . '"Postcode is required.",';
        }

        if ( $validation_message == '{"ErrorMessages":[' ) {
            return $validation_message;
        }

        return $this->check_if_end_of_validation( $validation_message );
    }

    //Validates the mobile number. If its the first validator to run it should start with '{"ErrorMessages":['
    private function validate_mobile( $validation_message ) {
        $validation_message = $this->check_if_start_of_validation( $validation_message );

        if ( ! $_POST['payadvantagemobile'] ) {
            $validation_message = $validation_message . '"Mobile phone number is required.",';
        }

        return $this->check_if_end_of_validation( $validation_message );
    }

    //Validates the credit card details. If its the first validator to run it should start with '{"ErrorMessages":['
    private function validate_credit_card_details( $validation_message ) {
        $validation_message = $this->check_if_start_of_validation( $validation_message );

        if ( ! $_POST['payadvantageamount'] ) {
            $validation_message = $validation_message . '"Amount is required.",';
        }

        if ( ! $this->card_holders_name( $_POST['payadvantagecardholdersname'] ) ) {
            $validation_message = $validation_message . '"Card Holders Name is invalid.",';
        }

        if ( ! $this->credit_card_number( $_POST['payadvantagecardnumber'] ) ) {
            $validation_message = $validation_message . '"Credit Card Number is invalid.",';
        }

        if ( ! $this->credit_card_ccv( $_POST['payadvantagecreditcardcode'])){
            $validation_message = $validation_message . '"Credit Card Code is invalid.",';
        }
                
        if ( ! $this->credit_card_expiry( $_POST['payadvantageexpirymonth'], $_POST['payadvantageexpiryyear'] ) ) {
            $validation_message = $validation_message . '"Expiry is Invalid.",';
        }       

        if ( $validation_message == '{"ErrorMessages":[' ) {
            return $validation_message;
        } 

        return $this->check_if_end_of_validation( $validation_message );
    }

     //Does a quick check to allow different validation methods to build from one another
    private function check_if_start_of_validation( $validation_message ) {
        if ( $validation_message != '{"ErrorMessages":[' ) {
            $validation_message = $validation_message . ',';
        };
        return $validation_message;
    }

    private function check_if_end_of_validation( $validation_message ) {
        if ( $validation_message == '{"ErrorMessages":[' ) {
            return $validation_message;
        }

        $validation_message = substr_replace( $validation_message, '', -1 );
        return $validation_message;
    }


    /**
     * Validator for the credit card number
     */
    public function credit_card_number( $credit_card_number ) {
        if ( ! is_numeric( $credit_card_number ) ) {
            return false;
        }

        $number_chars = strlen( $credit_card_number );
        if ( $number_chars < 15 || $number_chars > 16 ) {
            return false;
        }

        return $this->luhn_check($credit_card_number);
    }

    /**
     * Card holders name validator
     */
    public function card_holders_name( $name ) {
        $stringWithNoWhiteSpace = preg_replace('/\s+/', '', $name);

        if (is_numeric( $stringWithNoWhiteSpace )) {
            return false;
        }

        if (!ctype_alpha( $stringWithNoWhiteSpace )) {
            return false;
        }

        if ( $name == null ) {
            return false;
        }
        $name_array = explode( ' ', $name );
        if ( count( $name_array ) == 1 ) {
            return false;
        }
        return true;
    }

    /**
     * CCV code validator
     */
    public function credit_card_ccv( $ccv ) {
        if ( ! is_numeric( $ccv ) ) {
            return false;
        }

        $number_chars = strlen( $ccv );
        if ( $number_chars < 3 || $number_chars > 4 ) {
            return false;
        }

        return true;
    }

    /**
     * Validates the credit card expiry
     */
    public function credit_card_expiry( $month, $year ) {
        if ( ! is_numeric( $month ) || ! is_numeric( $year ) ) {
            return false;
        }

        $number_chars_month = strlen( $month );
        $number_chars_year = strlen( $year );
        $current_year = (int)date( 'Y' );
        $month_value_check = (int)$month;
        $year_value_check = (int)$year;

        if ( $number_chars_month > 2 || $month_value_check > 12 || $month_value_check < 0) {
            return false;
        }

        if ( $number_chars_year != 4 || $year_value_check < $current_year ) {
            return false;
        }
        
        $now =  new \DateTime();
        $expires = \DateTime::createFromFormat('mY', $month.$year)->modify('+1 month first day of midnight');;

        if ($expires < $now) {
            return false;
        }
        
        return true;
    }

    /* Luhn algorithm number checker - (c) 2005-2008 shaman - www.planzero.org */
    private function luhn_check($number) {

        // Strip any non-digits (useful for credit card numbers with spaces and hyphens)
        $number=preg_replace('/\D/', '', $number);
        
        // Set the string length and parity
        $number_length=strlen($number);
        $parity=$number_length % 2;
        
        // Loop through each digit and do the maths
        $total=0;
        for ($i=0; $i<$number_length; $i++) {
          $digit=$number[$i];
          // Multiply alternate digits by two
          if ($i % 2 == $parity) {
            $digit*=2;
            // If the sum is two digits, add them together (in effect)
            if ($digit > 9) {
              $digit-=9;
            }
          }
          // Total up the digits
          $total+=$digit;
        }
    
        // If the total mod 10 equals 0, the number is valid
        return ($total % 10 == 0) ? TRUE : FALSE;
  
  }
}

?>