<?php
/**
 * gets the result from an api call and returns either the body or sends it to an errorhandler for a response message.
 */

 class Pay_Advantage_Result_Processor{

    /**
     * Decides if the response is an error. Trys to filter error before API Error handler.
     */   
     public function process_result( $response, $stage, $request_type ) {
        $error_processor = new Pay_Advantage_Api_Error_Handler();
        $json_response = wp_remote_retrieve_body( $response );
        $generic_error_message = json_decode( '{"type":"' . $request_type . '", "ErrorMessages":["There is an issue processing your request, please contact vendor."] , "console":"' . $stage . '"}', '1');

        if ( is_wp_error( $response ) ) {
            $error_processor->log_error( json_encode( $response ) );
            return  $generic_error_message;
        }
        
        if ( !isset( $response['response'] ) ) {
            $error_processor->log_error( json_encode( $response ) );
            return  $generic_error_message;
        }

        try {
            if ( $response['response']['code'] > 300) {
                $error_processor->log_error( json_encode( $response ) );
                $error_messages = $error_processor->check_for_errors( $json_response, $request_type, $stage, $response['response']['code'] );
                return json_decode( $error_messages, 1 );
            }
        } catch ( Exception $e ) {
            $message = json_encode( $response );
            $error_processor->log_error( $message );
            return  $generic_error_message;
        }
        
        $json_response_object = json_decode( $json_response, 1 );
        if ( isset( $json_response_object['Payment']['FailReason'] ) ) {
            return array(
                'ErrorMessages' => array(
                    $json_response_object['Payment']['FailReason']
                )
            );
        }
        return $json_response_object;
    }
 }
 
 ?>